@@ -7,7 +7,7 @@ grml2usb
 
 This script installs a Grml system (either a running system or ISO[s]) to a USB device
 
-:copyright: (c) 2009-2019 by Michael Prokop <mika@grml.org>
+:copyright: (c) 2009-2025 by Michael Prokop <mika@grml.org>
 :license: GPL v2 or any later version
 :bugreports: http://grml.org/bugs/
 
@@ -76,6 +76,7 @@ Run %(prog)s --help for usage hints, further information via: man grml2usb"
 # pylint: disable-msg=W0603
 parser = argparse.ArgumentParser(usage=USAGE)
 bootloader_group = parser.add_mutually_exclusive_group()
+fat_group = parser.add_mutually_exclusive_group()
 
 parser.add_argument(
     "--bootoptions",
@@ -98,10 +99,17 @@ parser.add_argument(
 parser.add_argument(
     "--dry-run", dest="dryrun", action="store_true", help="avoid executing commands"
 )
-parser.add_argument(
+fat_group.add_argument(
+    "--format",
+    action="store_true",
+    help="format specified partition with fat",
+)
+fat_group.add_argument(
     "--fat16",
     action="store_true",
-    help="format specified partition with FAT16",
+    # deprecated=True, # python>=3.13
+    dest="format",
+    help="format specified partition with fat (deprecated option)",
 )
 parser.add_argument(
     "--force",
@@ -214,6 +222,7 @@ bootloader_group.add_argument(
     "--grub",
     dest="bootloader",
     action="store_const",
+    # deprecated=True, # python>=3.13
     const="grub",
     help="install grub bootloader (deprecated option)",
 )
@@ -221,6 +230,7 @@ bootloader_group.add_argument(
     "--syslinux",
     dest="bootloader",
     action="store_const",
+    # deprecated=True, # python>=3.13
     const="syslinux",
     help="install syslinux bootloader (deprecated option)",
 )
@@ -513,19 +523,19 @@ def check_boot_flag(device):
         )
 
 
-def mkfs_fat16(device):
-    """Format specified device with VFAT/FAT16 filesystem.
+def mkfs_vfat(device):
+    """Format specified device with FAT filesystem.
 
     @device: partition that should be formated"""
     assert options is not None
 
     if options.dryrun:
-        logging.info("Would execute mkfs.vfat -F 16 %s now.", device)
+        logging.info("Would execute mkfs.vfat %s now.", device)
         return 0
 
-    logging.info("Formating partition with fat16 filesystem")
-    logging.debug("mkfs.vfat -F 16 %s", device)
-    proc = subprocess.Popen(["mkfs.vfat", "-n", "GRML", "-F", "16", device])
+    logging.info("Formatting partition using mkfs.vfat")
+    logging.debug("mkfs.vfat %s", device)
+    proc = subprocess.Popen(["mkfs.vfat", "-n", "GRML", device])
     proc.wait()
     if proc.returncode != 0:
         raise CriticalException("error executing mkfs.vfat")
@@ -681,7 +691,7 @@ def install_syslinux(device):
     proc.wait()
     if proc.returncode != 0:
         raise CriticalException(
-            "Error executing syslinux (either try --fat16 or use grub?)"
+            "Error executing syslinux (either try --format or use grub?)"
         )
 
 
@@ -948,7 +958,7 @@ def check_for_usbdevice(device):
 
 
 def check_for_fat(partition):
-    """Check whether specified partition is a valid VFAT/FAT16 filesystem
+    """Check whether specified partition is a valid FAT filesystem
 
     @partition: device name of partition"""
 
@@ -969,8 +979,8 @@ def check_for_fat(partition):
 
         if filesystem != "vfat":
             raise CriticalException(
-                "Partition %s does not contain a FAT16 filesystem. "
-                "(Use --fat16 or run mkfs.vfat %s)" % (partition, partition)
+                "Partition %s does not contain a FAT filesystem. "
+                "(Use --format or run mkfs.vfat %s)" % (partition, partition)
             )
 
     except OSError:
@@ -1892,19 +1902,17 @@ def handle_vfat(device):
     assert options is not None
 
     # make sure we have mkfs.vfat available
-    if options.fat16:
+    if options.format:
         if not which("mkfs.vfat") and not options.copyonly and not options.dryrun:
             logging.critical("Sorry, mkfs.vfat not available. Exiting.")
             logging.critical("Please make sure to install dosfstools.")
             sys.exit(1)
 
         if options.force:
-            print("Forcing mkfs.fat16 on %s as requested via option --force." % device)
+            print("Forcing mkfs.vfat on %s as requested via option --force." % device)
         else:
             # make sure the user is aware of what he is doing
-            f = input(
-                "Are you sure you want to format the specified partition with fat16? y/N "
-            )
+            f = input("Are you sure you want to format the specified partition? y/N ")
             if f == "y" or f == "Y":
                 logging.info(
                     "Note: you can skip this question using the option --force"
@@ -1912,12 +1920,12 @@ def handle_vfat(device):
             else:
                 sys.exit(1)
         try:
-            mkfs_fat16(device)
+            mkfs_vfat(device)
         except CriticalException as error:
             logging.critical("Execution failed: %s", error)
             sys.exit(1)
 
-    # check for vfat filesystem
+    # check for fat filesystem
     if (
         device is not None
         and not os.path.isdir(device)
@@ -2090,7 +2098,7 @@ def main(grml2usb_options: argparse.Namespace):
     if not options.skipbootflag:
         check_boot_flag(device)
 
-    # check for vfat partition
+    # check for fat partition
     handle_vfat(device)
 
     # main operation (like installing files)
